==> haskell-tidal-1.6.1-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tidal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tidal
version:              1.6.1
visibility:           public
id:                   tidal-1.6.1-D1XvCqF4I6V4rBIYDIvUnO
key:                  tidal-1.6.1-D1XvCqF4I6V4rBIYDIvUnO
license:              GPL-3.0-only
copyright:            (c) Alex McLean and other contributors, 2020
maintainer:
    Alex McLean <alex@slab.org>, Mike Hodnick <mike.hodnick@gmail.com>

author:               Alex McLean
stability:            Experimental
homepage:             http://tidalcycles.org/
synopsis:             Pattern language for improvised music
description:
    Tidal is a domain specific language for live coding pattern.

category:             Sound
abi:                  defaf81c68e7a751a34f0d205f87f23a
exposed:              True
exposed-modules:
    Sound.Tidal.Bjorklund Sound.Tidal.Carabiner Sound.Tidal.Chords
    Sound.Tidal.Config Sound.Tidal.Context Sound.Tidal.Control
    Sound.Tidal.Core Sound.Tidal.EspGrid Sound.Tidal.Params
    Sound.Tidal.ParseBP Sound.Tidal.Pattern Sound.Tidal.Scales
    Sound.Tidal.Show Sound.Tidal.Simple Sound.Tidal.Stream
    Sound.Tidal.Tempo Sound.Tidal.Transition Sound.Tidal.UI
    Sound.Tidal.Utils Sound.Tidal.Version

import-dirs:          /usr/lib/ghc-8.10.3/site-local/tidal-1.6.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/tidal-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/tidal-1.6.1
hs-libraries:         HStidal-1.6.1-D1XvCqF4I6V4rBIYDIvUnO
depends:
    base-4.14.1.0 bifunctors-5.5.9-1vlz0Qe0Goz2x3SwTBUGPu
    bytestring-0.10.12.0 clock-0.8-GgyC1t0yogI8KcRGJ3XM3f
    colour-2.3.5-6K5xsF393Et2liBPOQr84i containers-0.6.2.1
    deepseq-1.4.4.0 hosc-0.18-6GHTq3XlLTxFje529F9p0p
    network-3.1.2.1-3E7d1o37g1F5xYAC4VK0KJ parsec-3.1.14.0
    primitive-0.7.1.0-BwsxIJTIcWp13XgtTdgayP
    random-1.2.0-LHRkkrhiGQLBP4uqbvAKDd text-1.2.4.1
    transformers-0.5.6.2 vector-0.12.1.2-HCJzCvMeU9f2WjtWVmO7dQ

haddock-interfaces:   /usr/share/doc/haskell-tidal/html/tidal.haddock
haddock-html:         /usr/share/doc/haskell-tidal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tidal-1.6.1-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tidal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tidal
version:              1.6.1
visibility:           public
id:                   tidal-1.6.1-LYUQYVKOn0pD3gIP8eyOUP
key:                  tidal-1.6.1-LYUQYVKOn0pD3gIP8eyOUP
license:              GPL-3.0-only
copyright:            (c) Alex McLean and other contributors, 2020
maintainer:
    Alex McLean <alex@slab.org>, Mike Hodnick <mike.hodnick@gmail.com>

author:               Alex McLean
stability:            Experimental
homepage:             http://tidalcycles.org/
synopsis:             Pattern language for improvised music
description:
    Tidal is a domain specific language for live coding pattern.

category:             Sound
abi:                  b43b30c71fbecb155be248c5fe14e9bc
exposed:              True
exposed-modules:
    Sound.Tidal.Bjorklund Sound.Tidal.Carabiner Sound.Tidal.Chords
    Sound.Tidal.Config Sound.Tidal.Context Sound.Tidal.Control
    Sound.Tidal.Core Sound.Tidal.EspGrid Sound.Tidal.Params
    Sound.Tidal.ParseBP Sound.Tidal.Pattern Sound.Tidal.Scales
    Sound.Tidal.Show Sound.Tidal.Simple Sound.Tidal.Stream
    Sound.Tidal.Tempo Sound.Tidal.Transition Sound.Tidal.UI
    Sound.Tidal.Utils Sound.Tidal.Version

import-dirs:          /usr/lib/ghc-8.10.3/site-local/tidal-1.6.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/tidal-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/tidal-1.6.1
hs-libraries:         HStidal-1.6.1-LYUQYVKOn0pD3gIP8eyOUP
depends:
    base-4.14.1.0 bifunctors-5.5.9-97AgVaNOc3G2MwRywVAePb
    bytestring-0.10.12.0 clock-0.8-GgyC1t0yogI8KcRGJ3XM3f
    colour-2.3.5-C2yo01exdHyGWbuquZoJsU containers-0.6.2.1
    deepseq-1.4.4.0 hosc-0.18-7NaXO1k57je3Q6JXvC66ra
    network-3.1.2.1-bbhqzSr4X54nurl4VXPGv parsec-3.1.14.0
    primitive-0.7.1.0-Ihs2IWvcLa44Akdh6iwTam
    random-1.2.0-2oMeoq1l81e2o54ELOj6Jv text-1.2.4.1
    transformers-0.5.6.2 vector-0.12.1.2-H4eLF7dv8NOKyZpgYZDRLA

haddock-interfaces:   /usr/share/doc/haskell-tidal/html/tidal.haddock
haddock-html:         /usr/share/doc/haskell-tidal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
